==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GeneratePreexistingEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.event.GeneratePreexistingEvent;
import io.ciera.tool.sql.ooaofooa.event.GeneratePreexistingEventSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class GeneratePreexistingEventSetImpl extends InstanceSet<GeneratePreexistingEventSet,GeneratePreexistingEvent> implements GeneratePreexistingEventSet {

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) generatepreexistingevent.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) generatepreexistingevent.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) act_smtset.add( generatepreexistingevent.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R714_generates_event_held_by_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) valueset.add( generatepreexistingevent.R714_generates_event_held_by_Value() );
        return valueset;
    }


    @Override
    public GeneratePreexistingEvent nullElement() {
        return GeneratePreexistingEventImpl.EMPTY_GENERATEPREEXISTINGEVENT;
    }

    @Override
    public GeneratePreexistingEventSet emptySet() {
      return new GeneratePreexistingEventSetImpl();
    }

    @Override
    public GeneratePreexistingEventSet value() {
        return this;
    }

    @Override
    public List<GeneratePreexistingEvent> elements() {
        return Arrays.asList(toArray(new GeneratePreexistingEvent[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GeneratePreexistingEventSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.ACT_SMTSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ACT_SMTSetImpl;
import io.ciera.tool.sql.ooaofooa.event.GeneratePreexistingEvent;
import io.ciera.tool.sql.ooaofooa.event.GeneratePreexistingEventSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GeneratePreexistingEventSetImpl extends InstanceSet<GeneratePreexistingEventSet,GeneratePreexistingEvent> implements GeneratePreexistingEventSet {

    public GeneratePreexistingEventSetImpl() {
    }

    public GeneratePreexistingEventSetImpl(Comparator<? super GeneratePreexistingEvent> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) generatepreexistingevent.setStatement_ID( ref_Statement_ID );
    }
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) generatepreexistingevent.setValue_ID( ref_Value_ID );
    }


    // selections
    @Override
    public ACT_SMTSet R603_is_a_ACT_SMT() throws XtumlException {
        ACT_SMTSet act_smtset = new ACT_SMTSetImpl();
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) act_smtset.add( generatepreexistingevent.R603_is_a_ACT_SMT() );
        return act_smtset;
    }
    @Override
    public ValueSet R714_generates_event_held_by_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( GeneratePreexistingEvent generatepreexistingevent : this ) valueset.add( generatepreexistingevent.R714_generates_event_held_by_Value() );
        return valueset;
    }


    @Override
    public GeneratePreexistingEvent nullElement() {
        return GeneratePreexistingEventImpl.EMPTY_GENERATEPREEXISTINGEVENT;
    }

    @Override
    public GeneratePreexistingEventSet emptySet() {
      return new GeneratePreexistingEventSetImpl();
    }

    @Override
    public GeneratePreexistingEventSet emptySet(Comparator<? super GeneratePreexistingEvent> comp) {
      return new GeneratePreexistingEventSetImpl(comp);
    }

    @Override
    public GeneratePreexistingEventSet value() {
        return this;
    }

    @Override
    public List<GeneratePreexistingEvent> elements() {
        return Arrays.asList(toArray(new GeneratePreexistingEvent[0]));
    }

}
